## <p align='center'>paragon</p>

<p align='center'>
  A tiny command line benchmarking utility (and a python library!)<br/><br/>
  <img src="https://github.com/terror/paragon/actions/workflows/ci.yml/badge.svg"/>
</p>

## Features
- Statistical analysis
- Cool progress bars
- Python library
- Export results to various file formats (todo)

## Usage

You can install the command line utility via pip:

```bash
$ pip install paragon
```

## Demo

[![asciicast](https://asciinema.org/a/fC4GTTlbRlTSUqAn7qQN20fTE.svg)](https://asciinema.org/a/fC4GTTlbRlTSUqAn7qQN20fTE)
